|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r70406 - in sandbox/assign_v2: boost/assign/v2/option boost/assign/v2/option/std_modifier libs/assign/v2/test/option libs/assign/v2/test/put/pipe/option
From: erwann.rogard_at_[hidden]
Date: 2011-03-22 15:56:04
Author: e_r
Date: 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
New Revision: 70406
URL: http://svn.boost.org/trac/boost/changeset/70406
Log:
upd assign_v2
Text files modified:
sandbox/assign_v2/boost/assign/v2/option/insert.hpp | 4 ++--
sandbox/assign_v2/boost/assign/v2/option/key.hpp | 6 +++---
sandbox/assign_v2/boost/assign/v2/option/push.hpp | 4 ++--
sandbox/assign_v2/boost/assign/v2/option/push_back.hpp | 4 ++--
sandbox/assign_v2/boost/assign/v2/option/push_front.hpp | 4 ++--
sandbox/assign_v2/boost/assign/v2/option/std_modifier.hpp | 6 +++---
sandbox/assign_v2/boost/assign/v2/option/std_modifier/include.hpp | 6 +++---
sandbox/assign_v2/boost/assign/v2/option/std_modifier/modifier.hpp | 31 +++++++++++++++----------------
sandbox/assign_v2/libs/assign/v2/test/option/std_modifier.h | 6 +++---
sandbox/assign_v2/libs/assign/v2/test/put/pipe/option/std_modifier.h | 6 +++---
10 files changed, 38 insertions(+), 39 deletions(-)
Modified: sandbox/assign_v2/boost/assign/v2/option/insert.hpp
==============================================================================
--- sandbox/assign_v2/boost/assign/v2/option/insert.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/insert.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -10,7 +10,7 @@
#ifndef BOOST_ASSIGN_V2_OPTION_INSERT_ER_2010_HPP
#define BOOST_ASSIGN_V2_OPTION_INSERT_ER_2010_HPP
#include <boost/assign/v2/option/std_modifier/modifier.hpp>
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_TAG(insert)
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD(insert)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_TAG(insert)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER(insert)
#endif // BOOST_ASSIGN_V2_OPTION_INSERT_ER_2010_HPP
Modified: sandbox/assign_v2/boost/assign/v2/option/key.hpp
==============================================================================
--- sandbox/assign_v2/boost/assign/v2/option/key.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/key.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -7,8 +7,8 @@
// Boost Software License, Version 1.0. (See accompanying file //
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) //
//////////////////////////////////////////////////////////////////////////////
-#ifndef BOOST_ASSIGN_V2_INTERPRETER_KEY_ER_2010_HPP
-#define BOOST_ASSIGN_V2_INTERPRETER_KEY_ER_2010_HPP
+#ifndef BOOST_ASSIGN_V2_OPTION_KEY_ER_2010_HPP
+#define BOOST_ASSIGN_V2_OPTION_KEY_ER_2010_HPP
#include <boost/assign/v2/interpreter/data.hpp>
#include <boost/assign/v2/option/data.hpp>
#include <boost/mpl/apply.hpp>
@@ -67,4 +67,4 @@
}// assign
}// boost
-#endif // BOOST_ASSIGN_V2_INTERPRETER_KEY_ER_2010_HPP
+#endif // BOOST_ASSIGN_V2_OPTION_KEY_ER_2010_HPP
Modified: sandbox/assign_v2/boost/assign/v2/option/push.hpp
==============================================================================
--- sandbox/assign_v2/boost/assign/v2/option/push.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/push.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -10,7 +10,7 @@
#ifndef BOOST_ASSIGN_V2_OPTION_PUSH_ER_2010_HPP
#define BOOST_ASSIGN_V2_OPTION_PUSH_ER_2010_HPP
#include <boost/assign/v2/option/std_modifier/modifier.hpp>
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_TAG(push)
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD(push)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_TAG(push)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER(push)
#endif // BOOST_ASSIGN_V2_OPTION_PUSH_ER_2010_HPP
Modified: sandbox/assign_v2/boost/assign/v2/option/push_back.hpp
==============================================================================
--- sandbox/assign_v2/boost/assign/v2/option/push_back.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/push_back.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -10,7 +10,7 @@
#ifndef BOOST_ASSIGN_V2_OPTION_PUSH_BACK_ER_2010_HPP
#define BOOST_ASSIGN_V2_OPTION_PUSH_BACK_ER_2010_HPP
#include <boost/assign/v2/option/std_modifier/modifier.hpp>
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_TAG(push_back)
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD(push_back)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_TAG(push_back)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER(push_back)
#endif // BOOST_ASSIGN_V2_OPTION_PUSH_BACK_ER_2010_HPP
Modified: sandbox/assign_v2/boost/assign/v2/option/push_front.hpp
==============================================================================
--- sandbox/assign_v2/boost/assign/v2/option/push_front.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/push_front.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -10,7 +10,7 @@
#ifndef BOOST_ASSIGN_V2_OPTION_PUSH_FRONT_ER_2010_HPP
#define BOOST_ASSIGN_V2_OPTION_PUSH_FRONT_ER_2010_HPP
#include <boost/assign/v2/option/std_modifier/modifier.hpp>
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_TAG(push_front)
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD(push_front)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_TAG(push_front)
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER(push_front)
#endif // BOOST_ASSIGN_V2_OPTION_PUSH_FRONT_ER_2010_HPP
Modified: sandbox/assign_v2/boost/assign/v2/option/std_modifier.hpp
==============================================================================
--- sandbox/assign_v2/boost/assign/v2/option/std_modifier.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/std_modifier.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -7,9 +7,9 @@
// Boost Software License, Version 1.0. (See accompanying file //
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) //
//////////////////////////////////////////////////////////////////////////////
-#ifndef BOOST_ASSIGN_V2_OPTION_STANDARD_ER_2010_HPP
-#define BOOST_ASSIGN_V2_OPTION_STANDARD_ER_2010_HPP
+#ifndef BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_ER_2010_HPP
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_ER_2010_HPP
#include <boost/assign/v2/option/std_modifier/modifier.hpp>
#include <boost/assign/v2/option/std_modifier/include.hpp>
-#endif // BOOST_ASSIGN_V2_OPTION_STANDARD_ER_2010_HPP
+#endif // BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_ER_2010_HPP
Modified: sandbox/assign_v2/boost/assign/v2/option/std_modifier/include.hpp
==============================================================================
--- sandbox/assign_v2/boost/assign/v2/option/std_modifier/include.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/std_modifier/include.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -7,11 +7,11 @@
// Boost Software License, Version 1.0. (See accompanying file //
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) //
//////////////////////////////////////////////////////////////////////////////
-#ifndef BOOST_ASSIGN_V2_OPTION_STANDARD_INCLUDE_ER_2010_HPP
-#define BOOST_ASSIGN_V2_OPTION_STANDARD_INCLUDE_ER_2010_HPP
+#ifndef BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_INCLUDE_ER_2010_HPP
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_INCLUDE_ER_2010_HPP
#include <boost/assign/v2/option/insert.hpp>
#include <boost/assign/v2/option/push.hpp>
#include <boost/assign/v2/option/push_back.hpp>
#include <boost/assign/v2/option/push_front.hpp>
-#endif // BOOST_ASSIGN_V2_OPTION_STANDARD_INCLUDE_ER_2010_HPP
+#endif // BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_INCLUDE_ER_2010_HPP
Modified: sandbox/assign_v2/boost/assign/v2/option/std_modifier/modifier.hpp
==============================================================================
--- sandbox/assign_v2/libs/assign/v2/test/option/std_modifier.h (original)
+++ sandbox/assign_v2/libs/assign/v2/test/option/std_modifier.h 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -7,8 +7,8 @@
// Boost Software License, Version 1.0. (See accompanying file //
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) //
//////////////////////////////////////////////////////////////////////////////
-#ifndef LIBS_ASSIGN_V2_TEST_OPTION_STANDARD_ER_2010_H
-#define LIBS_ASSIGN_V2_TEST_OPTION_STANDARD_ER_2010_H
+#ifndef LIBS_ASSIGN_V2_TEST_OPTION_STD_MODIFIER_ER_2010_H
+#define LIBS_ASSIGN_V2_TEST_OPTION_STD_MODIFIER_ER_2010_H
namespace test_assign_v2{
namespace xxx_option{
@@ -20,4 +20,4 @@
}// xxx_option
}// xxx_test_assign
-#endif // LIBS_ASSIGN_V2_TEST_OPTION_STANDARD_ER_2010_H
+#endif // LIBS_ASSIGN_V2_TEST_OPTION_STD_MODIFIER_ER_2010_H
Modified: sandbox/assign_v2/libs/assign/v2/test/put/pipe/option/std_modifier.h
==============================================================================
--- sandbox/assign_v2/libs/assign/v2/test/put/pipe/option/std_modifier.h (original)
+++ sandbox/assign_v2/libs/assign/v2/test/put/pipe/option/std_modifier.h 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -7,8 +7,8 @@
// Boost Software License, Version 1.0. (See accompanying file //
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) //
//////////////////////////////////////////////////////////////////////////////
-#ifndef LIBS_ASSIGN_V2_TEST_PUT_PIPE_OPTION_STANDARD_ER_2010_H
-#define LIBS_ASSIGN_V2_TEST_PUT_PIPE_OPTION_STANDARD_ER_2010_H
+#ifndef LIBS_ASSIGN_V2_TEST_PUT_PIPE_OPTION_STD_MODIFIER_ER_2010_H
+#define LIBS_ASSIGN_V2_TEST_PUT_PIPE_OPTION_STD_MODIFIER_ER_2010_H
namespace test_assign_v2{
namespace xxx_put{
@@ -24,4 +24,4 @@
}// xxx_put
}// xxx_test_assign
-#endif // LIBS_ASSIGN_V2_TEST_PUT_PIPE_OPTION_STANDARD_ER_2010_H
+#endif // LIBS_ASSIGN_V2_TEST_PUT_PIPE_OPTION_STD_MODIFIER_ER_2010_H
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/assign_v2/boost/assign/v2/option/std_modifier/modifier.hpp (original)
+++ sandbox/assign_v2/boost/assign/v2/option/std_modifier/modifier.hpp 2011-03-22 15:56:01 EDT (Tue, 22 Mar 2011)
@@ -7,10 +7,9 @@
// Boost Software License, Version 1.0. (See accompanying file //
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) //
//////////////////////////////////////////////////////////////////////////////
-#ifndef BOOST_ASSIGN_V2_OPTION_STANDARD_MODIFIER_ER_2010_HPP
-#define BOOST_ASSIGN_V2_OPTION_STANDARD_MODIFIER_ER_2010_HPP
+#ifndef BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_MODIFIER_ER_2010_HPP
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_MODIFIER_ER_2010_HPP
#include <boost/assign/v2/detail/keyword/ignore.hpp>
-//#include <boost/assign/v2/interpreter/modifier.hpp>
#include <boost/assign/v2/interpreter/fwd.hpp>
#include <boost/assign/v2/option/modifier.hpp>
#include <boost/preprocessor/cat.hpp>
@@ -26,13 +25,13 @@
}// assign
}// boost
-#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL_PTR(FUN)\
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL_PTR(FUN)\
template<typename C, typename T>\
void impl(C& cont, T* t)const{\
cont.FUN( t );\
}\
/**/
-#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL_LVALUE(FUN)\
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL_LVALUE(FUN)\
template<typename C, typename T>\
void impl(C& cont, T& t)const{\
cont.FUN( t );\
@@ -45,7 +44,7 @@
#include <boost/utility/enable_if.hpp>
#include <boost/type_traits/is_reference.hpp>
// disable_if necessary to avoid ambiguity resolution with GCC4.4
-#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL_RVALUE(FUN)\
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL_RVALUE(FUN)\
template<typename C, typename T>\
typename boost::disable_if<\
boost::is_reference<T>,\
@@ -55,17 +54,17 @@
cont.FUN( std::move( t ) );\
}\
/**/
-#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL(FUN)\
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL_LVALUE(FUN)\
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL_RVALUE(FUN)\
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL(FUN)\
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL_LVALUE(FUN)\
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL_RVALUE(FUN)\
/**/
#else
-#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL(FUN)\
-BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL_LVALUE(FUN)\
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL(FUN)\
+BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL_LVALUE(FUN)\
/**/
#endif // BOOST_ASSIGN_V2_ENABLE_CPP0X
-#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_TAG(FUN)\
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_TAG(FUN)\
namespace boost{\
namespace assign{\
namespace v2{\
@@ -75,8 +74,8 @@
}\
/**/
// Must be preceded by BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_TAG(FUN)
#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD(FUN)\
namespace boost{\
namespace assign{\
namespace v2{\
@@ -89,7 +88,7 @@
public:\
adapter_modifier(){}\
adapter_modifier( ignore_, ignore_ ){}\
- BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_IMPL(FUN)\
+ BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_IMPL(FUN)\
};\
\
}\
@@ -107,4 +106,4 @@
/**/
-#endif // BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_ER_2010_HPP
+#endif // BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_MODIFIER_ER_2010_HPP
Modified: sandbox/assign_v2/libs/assign/v2/test/option/std_modifier.h
==============================================================================
@@ -75,8 +74,8 @@
}\
/**/
-// Must be preceded by BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD_TAG(FUN)
-#define BOOST_ASSIGN_V2_OPTION_MODIFIER_STANDARD(FUN)\
+// Must be preceded by BOOST_ASSIGN_V2_OPTION_STD_MODIFIER_TAG(FUN)
+#define BOOST_ASSIGN_V2_OPTION_STD_MODIFIER(FUN)\
namespace boost{\
namespace assign{\